@@ -74,7 +74,7 @@ class Category(models.Model):
         return self.forums.all().count()
 
     def get_absolute_url(self):
-        return reverse('pybb:category', args=[self.id])
+        return reverse('pybb:category', kwargs={'pk': self.id})
 
     @property
     def topics(self):
@@ -115,7 +115,7 @@ class Forum(models.Model):
         self.save()
 
     def get_absolute_url(self):
-        return reverse('pybb:forum', args=[self.id])
+        return reverse('pybb:forum', kwargs={'pk': self.id})
 
     @property
     def posts(self):
@@ -177,7 +177,7 @@ class Topic(models.Model):
         return self.get_last_post()
 
     def get_absolute_url(self):
-        return reverse('pybb:topic', args=[self.id])
+        return reverse('pybb:topic', kwargs={'pk': self.id})
 
     def save(self, *args, **kwargs):
         if self.id is None:
@@ -246,7 +246,7 @@ class Post(RenderableItem):
         self.topic.forum.update_counters()
 
     def get_absolute_url(self):
-        return reverse('pybb:post', args=[self.id])
+        return reverse('pybb:post', kwargs={'pk': self.id})
 
     def delete(self, *args, **kwargs):
         self_id = self.id
@@ -314,7 +314,7 @@ class Profile(PybbProfile):
         verbose_name_plural = _('Profiles')
 
     def get_absolute_url(self):
-        return reverse('pybb:user', args=[self.user.username])
+        return reverse('pybb:user', kwargs={'username': self.user.username})
 
 
 class Attachment(models.Model):
@@ -335,7 +335,7 @@ class Attachment(models.Model):
         return self.name
 
     def get_absolute_url(self):
-        return reverse('pybb:attachment', args=[self.hash])
+        return reverse('pybb:attachment', kwargs={'pk': self.hash})
 
     def size_display(self):
         size = self.size
