@@ -31,39 +31,36 @@ class FeaturesTest(TestCase):
         mail.outbox = []
 
     def test_base(self):
-        client = Client()
         # Check index page
         url = reverse('pybb:index')
-        response = client.get(url)
+        response = self.client.get(url)
         tree = html.fromstring(response.content)
         self.assertContains(response, u'foo')
         self.assertContains(response, self.forum.get_absolute_url())
         self.assertTrue(defaults.PYBB_DEFAULT_TITLE in tree.xpath('//title')[0].text_content())
         self.assertEqual(len(response.context['categories']), 1)
 
+    def test_forum_page(self):
         # Check forum page
-        url = reverse('pybb:forum', args=[self.forum.id])
-        response = client.get(url)
+        response = self.client.get(self.forum.get_absolute_url())
+        self.assertEqual(response.context['forum'], self.forum)
         tree = html.fromstring(response.content)
         self.assertTrue(tree.xpath('//a[@href="%s"]' % self.topic.get_absolute_url()))
         self.assertTrue(tree.xpath('//title[contains(text(),"%s")]' % self.forum.name))
         self.assertFalse(tree.xpath('//a[contains(@href,"?page=")]'))
         self.assertFalse(response.context['is_paginated'])
 
-        # User page
-        response = client.get(reverse('pybb:user', args=[self.user.username]))
-        self.assertTrue(response.status_code==200)
-
+    def test_profile_edit(self):
         # Self profile edit
-        client.login(username='zeus', password='zeus')
-        response = client.get(reverse('pybb:edit_profile'))
-        self.assertTrue(response.status_code==200)
+        self.client.login(username='zeus', password='zeus')
+        response = self.client.get(reverse('pybb:edit_profile'))
+        self.assertEqual(response.status_code, 200)
         tree = html.fromstring(response.content)
         values = dict(tree.xpath('//form[@method="post"]')[0].form_values())
         values['signature'] = 'test signature'
-        response = client.post(reverse('pybb:edit_profile'), data=values, follow=True)
-        self.assertTrue(response.status_code==200)
-        client.get(self.post.get_absolute_url(), follow=True)
+        response = self.client.post(reverse('pybb:edit_profile'), data=values, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.client.get(self.post.get_absolute_url(), follow=True)
         self.assertContains(response, 'test signature')
 
 
@@ -80,9 +77,7 @@ class FeaturesTest(TestCase):
                          ((defaults.PYBB_FORUM_PAGE_SIZE + 3) / defaults.PYBB_FORUM_PAGE_SIZE) + 1)
 
     def test_bbcode_and_topic_title(self):
-        client = Client()
-        url = reverse('pybb:topic', args=[self.topic.id])
-        response = client.get(url)
+        response = self.client.get(self.topic.get_absolute_url())
         tree = html.fromstring(response.content)
         self.assertTrue(self.topic.name in tree.xpath('//title')[0].text_content())
         self.assertContains(response, self.post.body_html)
@@ -143,7 +138,7 @@ class FeaturesTest(TestCase):
         tree = html.fromstring(client.get(reverse('pybb:index')).content)
         self.assertFalse(tree.xpath('//a[@href="%s"]/parent::td[contains(@class,"unread")]' % topic.forum.get_absolute_url()))
         # Post message
-        response = client.post(reverse('pybb:add_post', args=[topic.id]), {'body': 'test tracking'}, follow=True)
+        response = client.post(reverse('pybb:add_post', kwargs={'topic_id': topic.id}), {'body': 'test tracking'}, follow=True)
         self.assertContains(response, 'test tracking')
         # Topic status - readed
         tree = html.fromstring(client.get(topic.forum.get_absolute_url()).content)
@@ -185,9 +180,9 @@ class FeaturesTest(TestCase):
 
         
         self.assertFalse(category.id in [c.id for c in client.get(reverse('pybb:index')).context['categories']])
-        self.assertTrue(client.get(category.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(forum_in_hidden.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(topic_in_hidden.get_absolute_url()).status_code==404)
+        self.assertEqual(client.get(category.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(forum_in_hidden.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(topic_in_hidden.get_absolute_url()).status_code, 404)
 
         self.assertNotContains(client.get(reverse('pybb:index')), forum_hidden.get_absolute_url())
         self.assertNotContains(client.get(reverse('pybb:feed', kwargs={'url': 'topics'})), topic_hidden.get_absolute_url())
@@ -195,36 +190,36 @@ class FeaturesTest(TestCase):
 
         self.assertNotContains(client.get(reverse('pybb:feed', kwargs={'url': 'posts'})), post_hidden.get_absolute_url())
         self.assertNotContains(client.get(reverse('pybb:feed', kwargs={'url': 'posts'})), post_in_hidden.get_absolute_url())
-        self.assertTrue(client.get(forum_hidden.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(topic_hidden.get_absolute_url()).status_code==404)
+        self.assertEqual(client.get(forum_hidden.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(topic_hidden.get_absolute_url()).status_code, 404)
 
         client.login(username='zeus', password='zeus')
         self.assertFalse(category.id in [c.id for c in client.get(reverse('pybb:index')).context['categories']])
         self.assertNotContains(client.get(reverse('pybb:index')), forum_hidden.get_absolute_url())
-        self.assertTrue(client.get(category.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(forum_in_hidden.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(topic_in_hidden.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(forum_hidden.get_absolute_url()).status_code==404)
-        self.assertTrue(client.get(topic_hidden.get_absolute_url()).status_code==404)
+        self.assertEqual(client.get(category.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(forum_in_hidden.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(topic_in_hidden.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(forum_hidden.get_absolute_url()).status_code, 404)
+        self.assertEqual(client.get(topic_hidden.get_absolute_url()).status_code, 404)
         self.user.is_staff = True
         self.user.save()
         self.assertTrue(category.id in [c.id for c in client.get(reverse('pybb:index')).context['categories']])
         self.assertContains(client.get(reverse('pybb:index')), forum_hidden.get_absolute_url())
-        self.assertFalse(client.get(category.get_absolute_url()).status_code==404)
-        self.assertFalse(client.get(forum_in_hidden.get_absolute_url()).status_code==404)
-        self.assertFalse(client.get(topic_in_hidden.get_absolute_url()).status_code==404)
-        self.assertFalse(client.get(forum_hidden.get_absolute_url()).status_code==404)
-        self.assertFalse(client.get(topic_hidden.get_absolute_url()).status_code==404)
+        self.assertNotEqual(client.get(category.get_absolute_url()).status_code, 404)
+        self.assertNotEqual(client.get(forum_in_hidden.get_absolute_url()).status_code, 404)
+        self.assertNotEqual(client.get(topic_in_hidden.get_absolute_url()).status_code, 404)
+        self.assertNotEqual(client.get(forum_hidden.get_absolute_url()).status_code, 404)
+        self.assertNotEqual(client.get(topic_hidden.get_absolute_url()).status_code, 404)
 
     def test_inactive(self):
         client = Client()
         client.login(username='zeus', password='zeus')
-        client.post(reverse('pybb:add_post', args=[self.topic.id]), {'body': 'test ban'}, follow=True)
-        self.assertTrue(len(Post.objects.filter(body='test ban'))==1)
+        response = client.post(reverse('pybb:add_post', kwargs={'topic_id': self.topic.id}), {'body': 'test ban'}, follow=True)
+        self.assertEqual(len(Post.objects.filter(body='test ban')), 1)
         self.user.is_active = False
         self.user.save()
-        client.post(reverse('pybb:add_post', args=[self.topic.id]), {'body': 'test ban 2'}, follow=True)
-        self.assertTrue(len(Post.objects.filter(body='test ban 2'))==0)
+        client.post(reverse('pybb:add_post', kwargs={'topic_id': self.topic.id}), {'body': 'test ban 2'}, follow=True)
+        self.assertEqual(len(Post.objects.filter(body='test ban 2')), 0)
 
     def get_csrf(self, form):
         return form.xpath('//input[@name="csrfmiddlewaretoken"]/@value')[0]
@@ -232,13 +227,13 @@ class FeaturesTest(TestCase):
     def test_csrf(self):
         client = Client(enforce_csrf_checks=True)
         client.login(username='zeus', password='zeus')
-        response = client.post(reverse('pybb:add_post', args=[self.topic.id]), {'body': 'test csrf'}, follow=True)
-        self.assertFalse(response.status_code==200)
+        response = client.post(reverse('pybb:add_post', kwargs={'topic_id': self.topic.id}), {'body': 'test csrf'}, follow=True)
+        self.assertNotEqual(response.status_code, 200)
         response = client.get(self.topic.get_absolute_url())
         form = html.fromstring(response.content).xpath('//form[@class="post-form"]')[0]
         token = self.get_csrf(form)
-        response = client.post(reverse('pybb:add_post', args=[self.topic.id]), {'body': 'test csrf', 'csrfmiddlewaretoken': token}, follow=True)
-        self.assertTrue(response.status_code==200)
+        response = client.post(reverse('pybb:add_post', kwargs={'topic_id': self.topic.id}), {'body': 'test csrf', 'csrfmiddlewaretoken': token}, follow=True)
+        self.assertEqual(response.status_code, 200)
 
     def test_user_blocking(self):
         user = User.objects.create_user('test', 'test@localhost', 'test')
@@ -246,7 +241,7 @@ class FeaturesTest(TestCase):
         self.user.save()
         client = Client()
         client.login(username='zeus', password='zeus')
-        self.assertTrue(client.get(reverse('pybb:block_user', args=[user.username]), follow=True).status_code==200)
+        self.assertEqual(client.get(reverse('pybb:block_user', args=[user.username]), follow=True).status_code, 200)
         user = User.objects.get(username=user.username)
         self.assertFalse(user.is_active)
 
@@ -263,59 +258,69 @@ class FeaturesTest(TestCase):
         self.assertContains(client.get(self.forum.get_absolute_url()), 'test <b>headline</b>')
 
     def test_quote(self):
-        client = Client()
-        client.login(username='zeus', password='zeus')
-        response = client.get(reverse('pybb:add_post', args=[self.topic.id]), data={'quote_id': self.post.id, 'body': 'test tracking'}, follow=True)
-        self.assertTrue(response.status_code==200)
+        self.client.login(username='zeus', password='zeus')
+        response = self.client.get(reverse('pybb:add_post', kwargs={'topic_id': self.topic.id}), data={'quote_id': self.post.id, 'body': 'test tracking'}, follow=True)
+        self.assertEqual(response.status_code, 200)
         self.assertContains(response, self.post.body)
 
     def test_edit_post(self):
         client = Client()
         client.login(username='zeus', password='zeus')
-        response = client.get(reverse('pybb:edit_post', args=[self.post.id]))
-        self.assertTrue(response.status_code==200)
+        response = client.get(reverse('pybb:edit_post', kwargs={'pk': self.post.id}))
+        self.assertEqual(response.status_code, 200)
         tree = html.fromstring(response.content)
         values = dict(tree.xpath('//form[@method="post"]')[0].form_values())
         values['body'] = 'test edit'
-        response = client.post(reverse('pybb:edit_post', args=[self.post.id]), data=values, follow=True)
-        self.assertTrue(response.status_code==200)
+        response = client.post(reverse('pybb:edit_post', kwargs={'pk': self.post.id}), data=values, follow=True)
+        self.assertEqual(response.status_code, 200)
+        response = client.get(self.post.get_absolute_url(), follow=True)
         self.assertContains(response, 'test edit')
         # Check admin form
         self.user.is_staff = True
-        response = client.get(reverse('pybb:edit_post', args=[self.post.id]))
-        self.assertTrue(response.status_code==200)
+        self.user.save()
+        response = client.get(reverse('pybb:edit_post', kwargs={'pk': self.post.id}))
+        self.assertEqual(response.status_code, 200)
         tree = html.fromstring(response.content)
         values = dict(tree.xpath('//form[@method="post"]')[0].form_values())
         values['body'] = 'test edit'
         values['login'] = 'new_login'
-        response = client.post(reverse('pybb:edit_post', args=[self.post.id]), data=values, follow=True)
-        self.assertTrue(response.status_code==200)
+        response = client.post(reverse('pybb:edit_post', kwargs={'pk': self.post.id}), data=values, follow=True)
+        self.assertEqual(response.status_code, 200)
         self.assertContains(response, 'test edit')
 
+    def test_admin_post_add(self):
+        self.user.is_staff = True
+        self.user.save()
+        self.client.login(username='zeus', password='zeus')
+        response = self.client.post(reverse('pybb:add_post', kwargs={'topic_id': self.topic.id}), data={'quote_id': self.post.id, 'body': 'test admin post', 'user': 'zeus'}, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, 'test admin post')
+
     def test_stick(self):
         self.user.is_superuser = True
-        client = Client()
-        client.login(username='zeus', password='zeus')
-        self.assertTrue(client.get(reverse('pybb:stick_topic', args=[self.topic.id]), follow=True).status_code==200)
-        self.assertTrue(client.get(reverse('pybb:unstick_topic', args=[self.topic.id]), follow=True).status_code==200)
+        self.user.save()
+        self.client.login(username='zeus', password='zeus')
+        self.assertEqual(self.client.get(reverse('pybb:stick_topic', kwargs={'pk': self.topic.id}), follow=True).status_code, 200)
+        self.assertEqual(self.client.get(reverse('pybb:unstick_topic', kwargs={'pk': self.post.id}), follow=True).status_code, 200)
 
     def test_delete_view(self):
         post = Post(topic=self.topic, user=self.user, body='test to delete')
         post.save()
-        client = Client()
-        client.login(username='zeus', password='zeus')
-        response = client.post(reverse('pybb:delete_post', args=[post.id]), follow=True)
-        self.assertTrue(response.status_code==200)
+        self.user.is_superuser = True
+        self.user.save()
+        self.client.login(username='zeus', password='zeus')
+        response = self.client.post(reverse('pybb:delete_post', args=[post.id]), follow=True)
+        self.assertEqual(response.status_code, 200)
         # Check that topic and forum exists ;)
-        self.assertTrue(Topic.objects.filter(id=self.topic.id).count()==1)
-        self.assertTrue(Forum.objects.filter(id=self.forum.id).count()==1)
+        self.assertEqual(Topic.objects.filter(id=self.topic.id).count(), 1)
+        self.assertEqual(Forum.objects.filter(id=self.forum.id).count(), 1)
 
         # Delete topic
-        response = client.post(reverse('pybb:delete_post', args=[self.post.id]), follow=True)
-        self.assertTrue(response.status_code==200)
-        self.assertTrue(Post.objects.filter(id=self.post.id).count()==0)
-        self.assertTrue(Topic.objects.filter(id=self.topic.id).count()==0)
-        self.assertTrue(Forum.objects.filter(id=self.forum.id).count()==1)
+        response = self.client.post(reverse('pybb:delete_post', args=[self.post.id]), follow=True)
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(Post.objects.filter(id=self.post.id).count(), 0)
+        self.assertEqual(Topic.objects.filter(id=self.topic.id).count(), 0)
+        self.assertEqual(Forum.objects.filter(id=self.forum.id).count(), 1)
 
     def test_open_close(self):
         self.user.is_superuser = True
@@ -323,26 +328,26 @@ class FeaturesTest(TestCase):
         client = Client()
         client.login(username='zeus', password='zeus')
         response = client.get(reverse('pybb:close_topic', args=[self.topic.id]), follow=True)
-        self.assertTrue(response.status_code==200)
+        self.assertEqual(response.status_code, 200)
         response = client.post(reverse('pybb:add_post', args=[self.topic.id]), {'body': 'test closed'}, follow=True)
-        self.assertTrue(response.status_code==403)
+        self.assertEqual(response.status_code, 403)
         response = client.get(reverse('pybb:open_topic', args=[self.topic.id]), follow=True)
-        self.assertTrue(response.status_code==200)
+        self.assertEqual(response.status_code, 200)
         response = client.post(reverse('pybb:add_post', args=[self.topic.id]), {'body': 'test closed'}, follow=True)
-        self.assertTrue(response.status_code==200)
+        self.assertEqual(response.status_code, 200)
 
     def test_subscription(self):
         user = User.objects.create_user(username='user2', password='user2', email='user2@example.com')
         client = Client()
         client.login(username='user2', password='user2')
         response = client.get(reverse('pybb:add_subscription', args=[self.topic.id]), follow=True)
-        self.assertTrue(response.status_code==200)
+        self.assertEqual(response.status_code, 200)
         self.assertTrue(user in list(self.topic.subscribers.all()))
         new_post = Post(topic=self.topic, user=self.user, body='test subscribtion юникод')
         new_post.save()
         self.assertTrue([msg for msg in mail.outbox if new_post.get_absolute_url() in msg.body])
         response = client.get(reverse('pybb:delete_subscription', args=[self.topic.id]), follow=True)
-        self.assertTrue(response.status_code==200)
+        self.assertEqual(response.status_code, 200)
         self.assertTrue(user not in list(self.topic.subscribers.all()))
 
     def test_topic_updated(self):
@@ -353,13 +358,17 @@ class FeaturesTest(TestCase):
         post.save()
         client = Client()
         response = client.get(self.forum.get_absolute_url())
-        self.assertTrue(response.context['topic_list'][0]==topic)
+        self.assertEqual(response.context['topic_list'][0], topic)
         sleep(1)
         post = Post(topic=self.topic, user=self.user, body='bbcode [b]test[b]')
         post.save()
         client = Client()
         response = client.get(self.forum.get_absolute_url())
-        self.assertTrue(response.context['topic_list'][0]==self.topic)
+        self.assertEqual(response.context['topic_list'][0], self.topic)
+
+    def test_user_view(self):
+        resp = self.client.get(reverse('pybb:user', kwargs={'username': self.user.username}))
+        self.assertEqual(resp.status_code, 200)
 
 
         
